@@ -20,8 +20,8 @@
 #	define PGRN_SUPPORT_CREATE_ACCESS_METHOD
 #endif
 
-#if PG_VERSION_NUM >= 90600
-#	define PGRN_SUPPORT_XLOG
+#if PG_VERSION_NUM >= 90600 && defined(PGRN_HAVE_MSGPACK)
+#	define PGRN_SUPPORT_WAL
 #endif
 
 #if PG_VERSION_NUM >= 90400
