@@ -219,7 +219,13 @@ PGrnJSONBCreateDataColumns(Relation index,
 	{
 		grn_column_flags flags = 0;
 		if (PGrnIsLZ4Available)
+		{
 			flags |= GRN_OBJ_COMPRESS_LZ4;
+		}
+		else if (PGrnIsZLIBAvailable)
+		{
+			flags |= GRN_OBJ_COMPRESS_ZLIB;
+		}
 		PGrnCreateColumn(index,
 						 jsonbData->valuesTable,
 						 "string",
@@ -1157,7 +1163,7 @@ PGrnJSONBInsertRecord(Relation index,
 }
 #endif
 
-void
+uint32_t
 PGrnJSONBInsert(Relation index,
 				grn_obj *sourcesTable,
 				grn_obj *sourcesCtidColumn,
@@ -1165,6 +1171,7 @@ PGrnJSONBInsert(Relation index,
 				bool *isnull,
 				uint64_t packedCtid)
 {
+	uint32_t recordSize = 0; /* always 0 */
 #ifdef PGRN_SUPPORT_JSONB
 	PGrnJSONBInsertData data;
 	unsigned int nthValue = 0;
@@ -1190,6 +1197,8 @@ PGrnJSONBInsert(Relation index,
 
 	PGrnJSONBInsertDataFin(&data);
 #endif
+
+	return recordSize;
 }
 
 #ifdef PGRN_SUPPORT_JSONB
@@ -1580,14 +1589,16 @@ PGrnJSONBBulkDeleteFin(PGrnJSONBBulkDeleteData *data)
 }
 
 #ifdef PGRN_SUPPORT_JSONB
-static bool
+static void
 PGrnRemoveJSONValueLexicon(const char *typeName, unsigned int relationID)
 {
 	char tableName[GRN_TABLE_MAX_KEY_SIZE];
 	snprintf(tableName, sizeof(tableName),
 			 PGrnJSONValueLexiconNameFormat,
 			 typeName, relationID, 0);
-	return PGrnRemoveObject(tableName);
+	if (!grn_ctx_get(ctx, tableName, -1))
+		return;
+	PGrnRemoveObject(tableName);
 }
 #endif
 
@@ -1595,6 +1606,15 @@ void
 PGrnJSONBRemoveUnusedTables(Oid relationFileNodeID)
 {
 #ifdef PGRN_SUPPORT_JSONB
+	{
+		char jsonValuesTableName[GRN_TABLE_MAX_KEY_SIZE];
+		snprintf(jsonValuesTableName, sizeof(jsonValuesTableName),
+				 PGrnJSONValuesTableNameFormat,
+				 relationFileNodeID, 0);
+		if (!grn_ctx_get(ctx, jsonValuesTableName, -1))
+			return;
+	}
+
 		PGrnRemoveJSONValueLexicon("FullTextSearch", relationFileNodeID);
 		PGrnRemoveJSONValueLexicon("String", relationFileNodeID);
 		PGrnRemoveJSONValueLexicon("Number", relationFileNodeID);
